Index: branches/2.8.x/CHANGELOG
===================================================================
--- branches/2.8.x/CHANGELOG	(revision 1900)
+++ branches/2.8.x/CHANGELOG	(revision 1901)
@@ -11,7 +11,8 @@
 ! = Update/Change
 ===============================================================================
 
-
+19 Apr-2013 Build 1901 Werner v.d.Decken(DarkViper)
+# little corrections in class Password
 18 Apr-2013 Build 1900 Werner v.d.Decken(DarkViper)
 + Classes Password / PasswordHash Added for an essential strengthening of the password security
 04 Apr-2013 Build 1899 Dietmar Woellbrink (Luisehahne)
Index: branches/2.8.x/wb/admin/interface/version.php
===================================================================
--- branches/2.8.x/wb/admin/interface/version.php	(revision 1900)
+++ branches/2.8.x/wb/admin/interface/version.php	(revision 1901)
@@ -51,5 +51,5 @@
 
 // check if defined to avoid errors during installation (redirect to admin panel fails if PHP error/warnings are enabled)
 if(!defined('VERSION')) define('VERSION', '2.8.3');
-if(!defined('REVISION')) define('REVISION', '1900');
+if(!defined('REVISION')) define('REVISION', '1901');
 if(!defined('SP')) define('SP', '');
Index: branches/2.8.x/wb/framework/initialize.php
===================================================================
--- branches/2.8.x/wb/framework/initialize.php	(revision 1900)
+++ branches/2.8.x/wb/framework/initialize.php	(revision 1901)
@@ -208,10 +208,6 @@
 	if(!function_exists('globalExceptionHandler')) {
 		include(dirname(__FILE__).'/globalExceptionHandler.php');
 	}
-// activate secure PasswordHashes
-	if(!class_exists('PasswordHash')) {
-		include(dirname(dirname(__FILE__)).'/include/phpass/PasswordHash.php'); 
-	}
 // ---------------------------
 // Create global database instance ---
 	$database = WbDatabase::getInstance();
Index: branches/2.8.x/wb/framework/Password.php
===================================================================
--- branches/2.8.x/wb/framework/Password.php	(revision 1900)
+++ branches/2.8.x/wb/framework/Password.php	(revision 1901)
@@ -36,13 +36,17 @@
  */
 
 // use \vendors\phpass\PasswordHash;
+if(!class_exists('PasswordHash')) {
+	include(dirname(dirname(__FILE__)).'/include/phpass/PasswordHash.php'); 
+}
 
+
 class Password extends PasswordHash
 //class Password extends v_phpass_PasswordHash
 {
 
 	const MIN_CRYPT_LOOPS     =  6;  // minimum numbers of loops is 2^6 (64) very, very quick
-	const MAX_CRYPT_LOOPS     = 32;  // maximum numbers of loops is 2^32 (4,294,967,296) extremely slow
+	const MAX_CRYPT_LOOPS     = 31;  // maximum numbers of loops is 2^31 (2,147,483,648) extremely slow
 	const DEFAULT_CRYPT_LOOPS = 12;  // default numbers of loopf is 2^12 (4096) a good average
 
 	const HASH_TYPE_PORTABLE  = true;  // use MD5 only
@@ -59,6 +63,7 @@
 	const PW_USE_ALL          = 0xFFFF; // use all possibilities
 
 /**
+ * 
  * @param int number of iterations as exponent of 2 (must be between 4 and 31)
  * @param bool TRUE = use MD5 only | FALSE = automatic
  */
@@ -70,7 +75,7 @@
  * @param string password to hash
  * @return string generated hash. Null if failed.
  */
-	public function HashPassword($sPassword)
+	public function hashPassword($sPassword)
 	{
 		$sNewHash = parent::HashPassword($sPassword);
 		return ($sNewHash == '*') ? null : $sNewHash;
@@ -80,7 +85,7 @@
  * @param string existing stored hash
  * @return bool true if PW matches the stored hash
  */
-	public function CheckPassword($sPassword, $sStoredHash)
+	public function checkPassword($sPassword, $sStoredHash)
 	{
 		// compatibility layer for deprecated, simple and old MD5 hashes
 		if(preg_match('/^[0-9a-f]{32}$/si', $sStoredHash)) {
